const categoriesService = require('./categoriesService');

async function categoriesRoutes(fastify, options) {
    fastify.get('/categories/:url', async (request, reply) => {
        const { url } = request.params;
        const category = await categoriesService.getCategoryByUrl(url);
        return category;
    });

    fastify.get('/categories/:nodeId/:departmentId', async (request, reply) => {
        const { nodeId, departmentId } = request.params;
        const category = await categoriesService.getCategoryByNodeIdAndDepartmentId(nodeId, departmentId);
        return category;
    });

  fastify.get('/categories/to-try-check', async (request, reply) => {
    try {
      const categories = await categoriesService.getCategoriesToTryCheck();
      return categories
    } catch (error) {
      console.error('Error in /categories/to-try-check route:', error);
      reply.status(500).send({ error: 'Internal Server Error' });
    }
  });

    fastify.put('/categories', async (request, reply) => {
        const { category } = request.body;
        try {
            const updatedCategory = await categoriesService.upsertCategory(category);
            return updatedCategory;
        } catch (error) {
            console.error('Internal Server Error:', error); // Log the error for debugging
            reply.status(500).send({ error: 'Internal Server Error' });
        }
    });
    fastify.put('/categories/batch', async (request, reply) => {
        const { categories } = request.body;

        try {
            const updatedCategories = await Promise.all(
                categories.map((category) => categoriesService.upsertCategory(category))
            );
            return updatedCategories;
        } catch (error) {
            reply.status(500).send({ error: 'Internal Server Error' });
        }
    });
    fastify.put('/categories/checked', async (request, reply) => {
        try {
            const { url } = request.query;
            categoriesService.updateCategoryCheckedAtByUrl(url);
            return { message: 'Category checkedAt timestamp updated successfully' };
        } catch (error) {
            reply.status(500).send({ error: 'Internal Server Error' });
        }
    });
}

module.exports = categoriesRoutes;